#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################################
# catdic.py - Equivalence dictionaries into Casio Cat format and raw ascii-like format
# (c) 2006 Florian Birée aka Thesa <florian.biree@laposte.net> ~ http://filyb.info/
#
# Version 0.1.2
#
# changelog:
#
# # 0.1.2 version:
#
#   o fix a problem with the cat equiv for 'P(' (0xFB)
#   o add a newcat equvi for 'x^-1' (0x9B)
#
# # 0.1.1 version:
#
#   o version aligned on casetta.py
#
# # 0.1.0 version:
#
#   o first release
#
############################################################################
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# http://www.gnu.org/copyleft/gpl.html
#
############################################################################

__author__ = "Florian Birée"
__version__ = "0.1.2"
copyright = "Florian Birée, 2006, under GNU/GPL (http://www.gnu.org/copyleft/gpl.html)"

#8 dictionaries :
#r2c : raw To cat
#or2c: 'octet' raw To cat, convert this characters after others in raw -> cat
#r2cl: raw To cat Last
#r2n : raw To new cat, characters for the New Cat format

#c2r : cat To raw
#or2c: 'octet' cat To raw
#r2cl: raw To cat Last, convert this characters after others in cat -> raw
#n2r : new cat to raw, charchaters for the New Cat format


#
#Warning : * and / are not converted.
# You *must* convert them to raw in last, or to cat in first, without this dic.
#

#Caractères identiques :
#A~Z 0~9 espaces , : ( ) . { } [ ] = ' " ~ * / #
#Retour à la ligne chr(13)
#0xFF -> fin de fichier


# convert this characters in raw after others

r2c = {}

#Fichier prog-CH-CL+ME
r2c[chr(247)+chr(204)]="\\DrawOn"
r2c[chr(247)+chr(220)]="\\DrawOff"
r2c[chr(247)+chr(74)]="\\S-Gph1 "
r2c[chr(247)+chr(75)]="\\S-Gph2 "
r2c[chr(247)+chr(76)]="\\S-Gph3 "
r2c[chr(247)+chr(80)]="\\Scatter"
r2c[chr(247)+chr(81)]="\\xyLine"
r2c[chr(247)+chr(82)]="\\Hist"
r2c[chr(247)+chr(83)]="\\MedBox"
r2c[chr(247)+chr(84)]="\\MeanBox"
r2c[chr(247)+chr(85)]="\\N-Dist"
r2c[chr(247)+chr(86)]="\\Broken"
r2c[chr(247)+chr(87)]="\\Linear"
r2c[chr(247)+chr(88)]="\\Med-Med"
r2c[chr(247)+chr(89)]="\\Quad"
r2c[chr(247)+chr(90)]="\\Cubic"
r2c[chr(247)+chr(91)]="\\Quart"
r2c[chr(247)+chr(92)]="\\Log"
r2c[chr(247)+chr(93)]="\\Exp"
r2c[chr(247)+chr(94)]="\\Power"
r2c[chr(127)+chr(106)]="\\List1"
r2c[chr(127)+chr(107)]="\\List2"
r2c[chr(127)+chr(108)]="\\List3"
r2c[chr(127)+chr(109)]="\\List4"
r2c[chr(127)+chr(110)]="\\List5"
r2c[chr(127)+chr(111)]="\\List6"
r2c[chr(247)+chr(77)]="\\Square"
r2c[chr(247)+chr(78)]="\\Cross"
r2c[chr(247)+chr(79)]="\\Dot"
r2c[chr(127)+chr(53)]="\\Blue "
r2c[chr(127)+chr(52)]="\\Orange "
r2c[chr(127)+chr(54)]="\\Green "
r2c[chr(247)+chr(64)]="\\1-Variable "
r2c[chr(247)+chr(65)]="\\2-Variable "
r2c[chr(247)+chr(66)]="\\LinearReg "
r2c[chr(247)+chr(67)]="\\Med-MedLine "
r2c[chr(247)+chr(68)]="\\QuadReg "
r2c[chr(247)+chr(69)]="\\CubicReg "
r2c[chr(247)+chr(70)]="\\QuartReg "
r2c[chr(247)+chr(71)]="\\LogReg "
r2c[chr(247)+chr(72)]="\\ExpReg "
r2c[chr(247)+chr(73)]="\\PowerReg "
r2c[chr(127)+chr(69)]="\\Swap("
r2c[chr(127)+chr(66)]="\\*Row("
r2c[chr(127)+chr(67)]="\\*Row+("
r2c[chr(127)+chr(68)]="\\Row+("
r2c[chr(247)+chr(176)]="\\SortA("
r2c[chr(247)+chr(177)]="\\SortD("
r2c[chr(247)+chr(200)]="\\G SelOn "
r2c[chr(247)+chr(216)]="\\G SelOff "
r2c[chr(247)+chr(99)]="\\Y=Type"
r2c[chr(247)+chr(100)]="\\r=Type"
r2c[chr(247)+chr(101)]="\\ParamType"
r2c[chr(247)+chr(103)]="\\X=cType"
r2c[chr(247)+chr(106)]="\\Y>Yype"
r2c[chr(247)+chr(107)]="\\Y<Type"
r2c[chr(247)+chr(108)]="\\Y>=Type"
r2c[chr(247)+chr(109)]="\\Y<=Type"
r2c[chr(127)+chr(56)]="\\BlueG "
r2c[chr(127)+chr(55)]="\\OrangeG "
r2c[chr(127)+chr(57)]="\\GreenG "
r2c[chr(247)+chr(149)]="\\StoGMEM "
r2c[chr(247)+chr(150)]="\\RclGMEM "
r2c[chr(247)+chr(202)]="\\D SelOn "
r2c[chr(247)+chr(218)]="\\D SelOff "
r2c[chr(247)+chr(128)]="\\D Var "
r2c[chr(247)+chr(101)]="\\ParamType"
r2c[chr(247)+chr(201)]="\\T SelOn "
r2c[chr(247)+chr(217)]="\\T SelOff "
r2c[chr(247)+chr(203)]="\\R SelOn "
r2c[chr(247)+chr(219)]="\\R SelOff "
r2c[chr(247)+chr(144)]="\\aRanType"
r2c[chr(247)+chr(145)]="a\\R n+Type"
r2c[chr(127)+chr(163)]="\\R n"
r2c[chr(127)+chr(160)]="a\\R n"
r2c[chr(127)+chr(161)]="a\\R n+"
r2c[chr(127)+chr(167)]="b\\R n"
r2c[chr(127)+chr(168)]="b\\R n+1"

#fichier prog-ch-opt
r2c[chr(127)+chr(81)]="\\List "
r2c[chr(127)+chr(74)]="\\List->Mat("
r2c[chr(127)+chr(70)]="\\Dim "
r2c[chr(127)+chr(71)]="\\Fill("
r2c[chr(127)+chr(44)]="\\Seq("
r2c[chr(127)+chr(45)]="\\Min("
r2c[chr(127)+chr(32)]="\\Max("
r2c[chr(127)+chr(46)]="\\Mean("
r2c[chr(127)+chr(47)]="\\Median("
r2c[chr(127)+chr(76)]="\\Sum "
r2c[chr(127)+chr(77)]="\\Prod "
r2c[chr(127)+chr(79)]="\\Cuml "
r2c[chr(127)+chr(78)]="\\Percent "
r2c[chr(127)+chr(64)]="\\Mat "
r2c[chr(127)+chr(75)]="\\Mat->List("
r2c[chr(127)+chr(33)]="\\Det "
r2c[chr(127)+chr(65)]="\\Trn "
r2c[chr(127)+chr(73)]="\\Augment("
r2c[chr(127)+chr(72)]="\\Identity "
r2c[chr(127)+chr(80)]="\\{i}"
r2c[chr(127)+chr(34)]="\\Arg "
r2c[chr(127)+chr(35)]="\\Conj "
r2c[chr(127)+chr(36)]="\\ReP "
r2c[chr(127)+chr(37)]="\\ImP "
r2c[chr(127)+chr(40)]="\\Solve("
r2c[chr(127)+chr(38)]="\\d/dx("
r2c[chr(127)+chr(39)]="\\d2/dxc("
r2c[chr(127)+chr(42)]="\\FMin("
r2c[chr(127)+chr(43)]="\\FMax("
r2c[chr(127)+chr(41)]="\\Sum("
r2c[chr(127)+chr(52)]="\\Orange "
r2c[chr(127)+chr(54)]="\\Green "
r2c[chr(247)+chr(147)]="\\StoPict "
r2c[chr(247)+chr(148)]="\\RclPict "
r2c[chr(127)+chr(176)]="\\ And "
r2c[chr(127)+chr(177)]="\\ Or "
r2c[chr(127)+chr(179)]="\\Not "

#fichier prog-ch-prgm
r2c[chr(247)+chr(0)]="\\If "
r2c[chr(247)+chr(1)]="\\Then "
r2c[chr(247)+chr(2)]="\\Else "
r2c[chr(247)+chr(3)]="\\IfEnd"
r2c[chr(247)+chr(4)]="\\For "
r2c[chr(247)+chr(5)]="\\ To "
r2c[chr(247)+chr(6)]="\\Step "
r2c[chr(247)+chr(7)]="\\Next"
r2c[chr(247)+chr(8)]="\\While "
r2c[chr(247)+chr(9)]="\\WhileEnd"
r2c[chr(247)+chr(10)]="\\Do"
r2c[chr(247)+chr(11)]="\\LpWhile "
r2c[chr(247)+chr(12)]="\\Return"
r2c[chr(247)+chr(13)]="\\Break"
r2c[chr(247)+chr(14)]="\\Stop"
r2c[chr(247)+chr(24)]="\\ClrText"
r2c[chr(247)+chr(25)]="\\ClrGraph"
r2c[chr(247)+chr(26)]="\\ClrList"
r2c[chr(247)+chr(35)]="\\DrawStat"
r2c[chr(247)+chr(32)]="\\DrawGraph"
r2c[chr(247)+chr(34)]="\\DrawDyna"
r2c[chr(247)+chr(46)]="\\DispF-Tbl"
r2c[chr(247)+chr(36)]="\\DrawFTG-Con"
r2c[chr(247)+chr(37)]="\\DrawFTG-Plt"
r2c[chr(247)+chr(47)]="\\DispR-Tbl"
r2c[chr(247)+chr(42)]="\\DrawWeb "
r2c[chr(247)+chr(38)]="\\DrawR-Con"
r2c[chr(247)+chr(40)]="\\DrawR-SumCon"
r2c[chr(247)+chr(39)]="\\DrawR-Plt"
r2c[chr(247)+chr(41)]="\\DrawR-SumPlt"
r2c[chr(247)+chr(16)]="\\Locate "
r2c[chr(127)+chr(143)]="\\Getkey"
r2c[chr(247)+chr(17)]="\\Send("
r2c[chr(247)+chr(18)]="\\Receive("

#fichier prog-ch-sec
r2c[chr(247)+chr(151)]="\\StoV-Win "
r2c[chr(247)+chr(152)]="\\RclV-Win "
r2c[chr(247)+chr(160)]="\\Tangent "
r2c[chr(247)+chr(161)]="\\Normal "
r2c[chr(247)+chr(162)]="\\Inverse "
r2c[chr(247)+chr(98)]="\\Graph X="
r2c[chr(247)+chr(168)]="\\PlotOn "
r2c[chr(247)+chr(169)]="\\PlotOff "
r2c[chr(247)+chr(170)]="\\PlotChg "
r2c[chr(247)+chr(167)]="\\F-Line "
r2c[chr(247)+chr(166)]="\\Circle "
r2c[chr(247)+chr(163)]="\\Vertical "
r2c[chr(247)+chr(164)]="\\Horizontal "
r2c[chr(247)+chr(165)]="\\Text "
r2c[chr(247)+chr(171)]="\\PxlOn "
r2c[chr(247)+chr(172)]="\\PxlOff "
r2c[chr(247)+chr(173)]="\\PxlChg "
r2c[chr(247)+chr(175)]="\\PxlTest "

#fichier prog-ch-setup
r2c[chr(247)+chr(195)]="\\CoordOn"
r2c[chr(247)+chr(211)]="\\CoordOff"
r2c[chr(247)+chr(125)]="\\GridOn"
r2c[chr(247)+chr(122)]="\\GridOff"
r2c[chr(247)+chr(194)]="\\AxesOn"
r2c[chr(247)+chr(210)]="\\AxesOff"
r2c[chr(247)+chr(196)]="\\LabelOn"
r2c[chr(247)+chr(212)]="\\LabelOff"
r2c[chr(127)+chr(50)]="\\P/L-Blue"
r2c[chr(127)+chr(49)]="\\P/L-Orange"
r2c[chr(127)+chr(51)]="\\P/L-Green"
r2c[chr(247)+chr(112)]="\\G-Connect"
r2c[chr(247)+chr(113)]="\\G-Plot"
r2c[chr(247)+chr(197)]="\\DerivOn"
r2c[chr(247)+chr(213)]="\\DerivOff"
r2c[chr(247)+chr(120)]="\\BG-None"
r2c[chr(247)+chr(121)]="\\BG-Pict "
r2c[chr(247)+chr(192)]="\\FuncOn"
r2c[chr(247)+chr(208)]="\\FuncOff"
r2c[chr(247)+chr(193)]="\\SimulOn"
r2c[chr(247)+chr(209)]="\\SimulOff"
r2c[chr(247)+chr(96)]="\\S-WindAuto"
r2c[chr(247)+chr(97)]="\\S-WindMan"
r2c[chr(247)+chr(184)]="\\File1"
r2c[chr(247)+chr(185)]="\\File2"
r2c[chr(247)+chr(186)]="\\File3"
r2c[chr(247)+chr(187)]="\\File4"
r2c[chr(247)+chr(188)]="\\File5"
r2c[chr(247)+chr(189)]="\\File6"
r2c[chr(247)+chr(198)]="\\LocusOn"
r2c[chr(247)+chr(214)]="\\LocusOff"
r2c[chr(247)+chr(136)]="\\VarRange"
r2c[chr(247)+chr(178)]="\\VarList1"
r2c[chr(247)+chr(179)]="\\VarList2"
r2c[chr(247)+chr(180)]="\\VarList3"
r2c[chr(247)+chr(181)]="\\VarList4"
r2c[chr(247)+chr(182)]="\\VarList5"
r2c[chr(247)+chr(183)]="\\VarList6"
r2c[chr(247)+chr(199)]="\\SumDispOn"
r2c[chr(247)+chr(215)]="\\SumDispOff"

#fichier prog-ch-vars
r2c[chr(127)+chr(0)]="\\Xmin"
r2c[chr(127)+chr(1)]="\\Xmax"
r2c[chr(127)+chr(2)]="\\Xscl"
r2c[chr(127)+chr(4)]="\\Ymin"
r2c[chr(127)+chr(5)]="\\Ymax"
r2c[chr(127)+chr(6)]="\\Yscl"
r2c[chr(127)+chr(8)]="\\Tmin"
r2c[chr(127)+chr(9)]="\\Tmax"
r2c[chr(127)+chr(10)]="\\Tptch"
r2c[chr(127)+chr(16)]="\\RightXmin"
r2c[chr(127)+chr(17)]="\\RightXmax"
r2c[chr(127)+chr(18)]="\\RightXscl"
r2c[chr(127)+chr(20)]="\\RightYmin"
r2c[chr(127)+chr(21)]="\\RightYmax"
r2c[chr(127)+chr(22)]="\\RightYscl"
r2c[chr(127)+chr(24)]="\\RightTmin"
r2c[chr(127)+chr(25)]="\\RightTmax"
r2c[chr(127)+chr(26)]="\\RigtTptch"
r2c[chr(127)+chr(11)]="\\Xfct"
r2c[chr(127)+chr(12)]="\\Yfct"
r2c[chr(127)+chr(118)]="\\Q1"
r2c[chr(127)+chr(119)]="\\Q3"
r2c[chr(127)+chr(120)]="\\x1"
r2c[chr(127)+chr(122)]="\\x2"
r2c[chr(127)+chr(124)]="\\x3"
r2c[chr(127)+chr(121)]="\\y1"
r2c[chr(127)+chr(123)]="\\y2"
r2c[chr(127)+chr(125)]="\\y3"
r2c[chr(127)+chr(240)]="\\Y "
r2c[chr(127)+chr(241)]="\\{r} "
r2c[chr(127)+chr(242)]="\\Xt "
r2c[chr(127)+chr(243)]="\\Yt "
r2c[chr(127)+chr(13)]="\\D Start"
r2c[chr(127)+chr(14)]="\\D End"
r2c[chr(127)+chr(15)]="\\D pitch"
r2c[chr(127)+chr(145)]="\\F Start"
r2c[chr(127)+chr(146)]="\\F End"
r2c[chr(127)+chr(147)]="\\F pitch"
r2c[chr(127)+chr(144)]="\\F Result"
r2c[chr(127)+chr(160)]="a\\R n"
r2c[chr(127)+chr(161)]="a\\R n+"
r2c[chr(127)+chr(167)]="b\\R n"
r2c[chr(127)+chr(168)]="b\\R n+"
r2c[chr(127)+chr(149)]="\\R Start"
r2c[chr(127)+chr(150)]="\\R End"
r2c[chr(127)+chr(173)]="a\\R nStart"
r2c[chr(127)+chr(174)]="b\\R nStart"
r2c[chr(127)+chr(148)]="\\R Result"
r2c[chr(127)+chr(98)]="\\Sim Result"
r2c[chr(127)+chr(96)]="\\Sim Coef"
r2c[chr(127)+chr(99)]="\\Ply Result"
r2c[chr(127)+chr(97)]="\\Ply Coef"

#Build the cat2raw dic
c2r = {}
for a, f in r2c.items():
    c2r[f] = a
#Add other equivalence for space mistakes:
c2r[" \\And "] = chr(127)+chr(176)
c2r[" \\Or "] = chr(127)+chr(177)
c2r[" \\To "] = chr(247)+chr(5)


##Octet-Raw2Cat (or2c)
or2c = {}
or2c[chr(134)]="\\sqrt"
or2c[chr(139)]="\\x^2"
or2c[chr(184)]="\\xrt"
or2c[chr(206)]="\\theta"
or2c[chr(181)]="\\10^x"
or2c[chr(149)]="\\log "
or2c[chr(165)]="\\e^x"
or2c[chr(145)]="\\asin"
or2c[chr(129)]="\\sin"
or2c[chr(146)]="\\acos"
or2c[chr(130)]="\\cos"
or2c[chr(147)]="\\atan"
or2c[chr(131)]="\\tan"
or2c[chr(187)]="\\ab/c"
or2c[chr(150)]="\\curt"
or2c[chr(14)]="\\->"
or2c[chr(208)]="\\Pi"
or2c[chr(192)]="\\Ans"
or2c[chr(15)]="\\E"
or2c[chr(135)]="\\(-)"
#or2c["*"]="\\aster"   ### *Must* be converted to raw in last, or to cat in first, without this dic.
#or2c[chr(47)]="\\slash" ### *idem*
#fichier prog-chln
or2c[chr(133)]="\\In " ## !!CAT \\In for ln
or2c[chr(151)]="\\Abs "
or2c[chr(141)]="\\Integral("
or2c[chr(203)]="\\Eox"
or2c[chr(204)]="\\Eoy"
or2c[chr(161)]="\\sinh "
or2c[chr(162)]="\\cosh "
or2c[chr(163)]="\\tanh "
or2c[chr(177)]="\\asinh "
or2c[chr(178)]="\\acosh "
or2c[chr(179)]="\\atanh "
or2c[chr(171)]="!" #(!= "!")
or2c[chr(136)]="\\nPr"
or2c[chr(152)]="\\nCr"
or2c[chr(193)]="\\Ran#"
or2c[chr(251)]="\\ProbP(" ##v0.1.2
#or2c[chr(81)]="\\ProbQ("  #conflict with Q
#or2c[chr(82)]="\\ProbR("  #conflict with R
or2c[chr(151)]="\\Abs "
or2c[chr(166)]="\\Int "
or2c[chr(182)]="\\Frac "
or2c[chr(211)]="\\Rnd"
or2c[chr(222)]="\\Intg "
or2c[chr(156)]="\\Deg>"
or2c[chr(172)]="\\Rad>"
or2c[chr(188)]="\\Gra>"
or2c[chr(140)]="\\Dms"
or2c[chr(128)]="\\Pol("
or2c[chr(160)]="\\Rec("
or2c[chr(5)]="\\milli"
or2c[chr(4)]="\\micro"
or2c[chr(3)]="\\nano"
or2c[chr(2)]="\\pico"
or2c[chr(1)]="\\fempto"
or2c[chr(6)]="\\kilo"
or2c[chr(7)]="\\Mega"
or2c[chr(8)]="\\Giga"
or2c[chr(9)]="\\Tera"
or2c[chr(10)]="\\Peta"
or2c[chr(11)]="\\Exa"
or2c[chr(20)]="\\f1"
or2c[chr(21)]="\\f2"
or2c[chr(22)]="\\f3"
or2c[chr(23)]="\\f4"
or2c[chr(24)]="\\f5"
or2c[chr(25)]="\\f6"
or2c[chr(237)]="\\Prog "
or2c[chr(226)]="\\Lbl "
or2c[chr(236)]="\\Goto "
or2c[chr(19)]="\\=>"
or2c[chr(233)]="\\Isz "
or2c[chr(232)]="\\Dsz "
or2c[chr(63)]="?"                      #(!= "?")
or2c[chr(12)]="\\Disp" + chr(13)       #(+retour à la ligne)
or2c[chr(17)]="\\<>"
or2c[chr(18)]="\\>="
or2c[chr(16)]="\\<="
or2c[chr(58)]=":"
or2c[chr(234)]="\\Factor "
or2c[chr(235)]="\\ViewWindow "
or2c[chr(209)]="\\Cls"
or2c[chr(238)]="\\Graph Y="
or2c[chr(244)]="\\Graph r="
or2c[chr(245)]="\\Graph (X,Y)=("
or2c[chr(239)]="\\Graph Integral "
or2c[chr(240)]="\\Graph Y>"
or2c[chr(241)]="\\Graph Y<"
or2c[chr(242)]="\\Graph Y>="
or2c[chr(243)]="\\Graph Y<="
or2c[chr(224)]="\\Plot "
or2c[chr(225)]="\\Line"
or2c[chr(218)]="\\Deg"
or2c[chr(219)]="\\Rad"
or2c[chr(220)]="\\Gra"
or2c[chr(227)]="\\Fix "
or2c[chr(228)]="\\Sci "
or2c[chr(217)]="\\Norm"
or2c[chr(221)]="\\Eng"
or2c[chr(159)]="\\Sumx"
or2c[chr(143)]="\\Sumx2"
or2c[chr(196)]="\\Sdx"
or2c[chr(197)]="\\Sdxn"
or2c[chr(174)]="\\minX"
or2c[chr(190)]="\\maxX"
or2c[chr(195)]="\\Meany"
or2c[chr(207)]="\\Sumy"
or2c[chr(191)]="\\Sumy2"
or2c[chr(223)]="\\Sumxy"
or2c[chr(198)]="\\Sdy"
or2c[chr(199)]="\\Sdyn"
or2c[chr(173)]="\\minY"
or2c[chr(189)]="\\maxY"
or2c[chr(158)]="\\Med"
or2c[chr(142)]="\\Mo"
or2c[chr(175)]="\\Cnt"
or2c[chr(202)]="\\Cor"

#Build the octet-cat2raw dic
oc2r = {}
for a,f in or2c.items():
    oc2r[f] = a

##Raw2Cat Last (r2cl)
r2cl = {}
r2cl[chr(168)]="^"
r2cl[chr(169)]="*" #(!= astérisque)
r2cl[chr(185)]="/"
r2cl[chr(137)]="+"
r2cl[chr(153)]="-"
r2cl[chr(61)]="="
r2cl[chr(62)]=">"
r2cl[chr(60)]="<"

#Build the cat2raw last dic
c2rl = {}
for a, f in r2cl.items():
    c2rl[f] = a

##New cat (r2n)
r2n = {}
r2n[chr(247)+chr(51)]="\\Sinusoidal"
r2n[chr(247)+chr(50)]="\\NPPlot"
r2n[chr(247)+chr(53)]="\\Logistic"
r2n[chr(247)+chr(52)]="\\SinReg "
r2n[chr(247)+chr(54)]="\\LogisticReg "
r2n[chr(247)+chr(146)]="a\\R n+2Type"
r2n[chr(127)+chr(82)]="\\DeltaList "
r2n[chr(247)+chr(118)]="\\Resid-None"
r2n[chr(247)+chr(119)]="\\Resid-List "
r2n[chr(127)+chr(151)]="\\H Start"
r2n[chr(127)+chr(152)]="\\H pitch"
r2n[chr(127)+chr(192)]="\\n1"
r2c[chr(127)+chr(193)]="\\n2"
r2n[chr(127)+chr(194)]="\\Test x1"
r2n[chr(127)+chr(195)]="\\Test x2"
r2n[chr(127)+chr(196)]="\\x1on-1"
r2n[chr(127)+chr(197)]="\\x2on-1"
r2n[chr(127)+chr(198)]="\\xpon-1"
r2n[chr(127)+chr(208)]="\\{F}"
r2n[chr(127)+chr(215)]="\\Fdf"
r2n[chr(127)+chr(218)]="\\SS"
r2n[chr(127)+chr(219)]="\\MS"
r2n[chr(127)+chr(216)]="\\Edf"
r2n[chr(127)+chr(220)]="\\SSe"
r2n[chr(127)+chr(221)]="\\MSe"
r2n[chr(127)+chr(210)]="\\{p}"
r2n[chr(127)+chr(209)]="\\{z}"
r2n[chr(127)+chr(211)]="\\{t}"
r2n[chr(127)+chr(213)]="\\chi2"
r2n[chr(127)+chr(202)]="\\Left"
r2n[chr(127)+chr(203)]="\\Right"
r2n[chr(127)+chr(199)]="\\p^"
r2n[chr(127)+chr(200)]="\\p^1"
r2c[chr(127)+chr(201)]="\\p^2"
r2n[chr(127)+chr(217)]="\\df"
r2n[chr(127)+chr(212)]="\\{s}"
r2n[chr(127)+chr(214)]="\\r2"
r2n[chr(127)+chr(244)]="\\{X}"
r2n[chr(127)+chr(164)]="\\a0"
r2c[chr(127)+chr(166)]="\\a1"
r2c[chr(127)+chr(165)]="\\a2"
r2n[chr(127)+chr(170)]="b0"
r2c[chr(127)+chr(171)]="\\b1"
r2c[chr(127)+chr(172)]="\\b2"
r2n[chr(127)+chr(100)]="\\{n}" #Conflict with \nCr and others
r2n[chr(127)+chr(101)]="\\I%"
r2n[chr(127)+chr(102)]="\\PV"
r2n[chr(127)+chr(103)]="\\PMT"
r2n[chr(127)+chr(104)]="\\FV"
r2n[chr(127)+chr(204)]="\\P/Y"
r2n[chr(127)+chr(205)]="\\C/Y"
r2n[chr(127)+chr(29)]="\\{c}"
r2n[chr(127)+chr(30)]="\\{d}"
r2n[chr(127)+chr(31)]="\\{e}"
r2n[chr(127)+chr(162)]="a\\R n+2"
r2n[chr(127)+chr(169)]="b\\R n+1"

#Build the NewCat2raw dic
n2r = {}
for a, f in r2n.items():
    n2r[f] = a

##Octet-Raw2NewCat dic (or2c)
or2n = {}
#or2n[chr(139)]="\\r"
or2n[chr(205)]="\\(r)"
#or2n[chr(84)]="\\Probt(" ##Lettre T
or2n[chr(200)]="\\{a}"
or2n[chr(201)]="\\{b}"
or2n[chr(202)]="\\S r"
or2c[chr(133)]="\\Ln " # en plus de cat "\In "
or2c[chr(0x9B)]="\\x^-1" # New cat equiv for x^-1 (155 - 0x9B) ##v0.1.2

#Build the octet-NewCat2raw dic
on2r = {}
for a, f in or2n.items():
    on2r[f] = a
